@@ -1,6 +1,5 @@
 package urpm::cfg;
 
-# $Id: cfg.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use warnings;
@@ -96,7 +95,7 @@ sub expand_line {
     return $line;
 }
 
-my $no_para_option_regexp = 'update|ignore|synthesis|noreconfigure|no-suggests|no-media-info|static|virtual|disable-certificate-check';
+my $no_para_option_regexp = 'update|ignore|synthesis|noreconfigure|no-recommends|no-suggests|no-media-info|static|virtual|disable-certificate-check';
 
 sub load_config_raw {
     my ($file, $b_norewrite) = @_;
@@ -164,8 +163,12 @@ sub load_config_raw {
 	} elsif (/^(hdlist|synthesis)$/) {
 	    # ignored, kept for compatibility
 	} elsif (/^($no_para_option_regexp)$/) {
+	    my $opt = $1;
+	    if ($opt =~ s/no-suggests/no-recommends/) { # COMPAT
+	        warn "WARNING: --no-suggests is deprecated. Use --no-recommends instead\n" if s/no-suggests/no-recommends/; # COMPAT
+	    }
 	    #- positive flags
-	    $block->{$1} = 1;
+	    $block->{$opt} = 1;
 	} elsif (my ($no, $k, $v) =
           /^(no-)?(
 	    verify-rpm
@@ -251,7 +254,6 @@ sub dump_config_raw {
 
 1;
 
-__END__
 
 =back
 
@@ -261,4 +263,6 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2017 Mageia
+
 =cut
