@@ -1,6 +1,5 @@
 package urpm::util;
 
-# $Id: util.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use Exporter;
@@ -18,6 +17,7 @@ our @EXPORT = qw(add2hash_
     file2absolute_file
     file_size
     find
+    formatList
     intersection
     max
     member 
@@ -65,7 +65,7 @@ sub reduce_pathname {
     #- clean url to remove any macro (which cannot be solved now).
     #- take care if this is a true url and not a simple pathname.
     my ($host, $dir) = $url =~ m|([^:/]*://[^/]*/)?(.*)|;
-    $host = '' if !defined $host;
+    $host //= '';
 
     #- remove any multiple /s or trailing /.
     #- then split all components of pathname.
@@ -217,12 +217,13 @@ sub append_to_file {
 
 1;
 
-__END__
 
 =head1 NAME
 
 urpm::util - Misc. utilities subs for urpmi
 
+Mostly a subset of L<MDK::Common>
+
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -233,4 +234,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2017 Mageia
+
 =cut
